package com.guna.ocrlibrary;

import android.app.Activity;
import android.content.Intent;
import android.database.Cursor;
import android.graphics.Bitmap;
import android.net.Uri;
import android.provider.MediaStore;
import android.util.Log;
import android.util.SparseArray;
import com.google.android.gms.vision.Frame;
import com.google.android.gms.vision.text.TextBlock;
import com.google.android.gms.vision.text.TextRecognizer;
import java.io.IOException;
import java.util.Arrays;

public class OCRCapture {
    private static final String TAG = OCRCapture.class.getSimpleName();
    private Activity activity;
    private boolean autoFocus;
    private boolean useFlash;

    private OCRCapture(Activity activity2) {
        this.activity = activity2;
    }

    public static OCRCapture Builder(Activity activity2) {
        return new OCRCapture(activity2);
    }

    public boolean isUseFlash() {
        return this.useFlash;
    }

    public OCRCapture setUseFlash(boolean useFlash2) {
        this.useFlash = useFlash2;
        return this;
    }

    public boolean isAutoFocus() {
        return this.autoFocus;
    }

    public OCRCapture setAutoFocus(boolean autoFocus2) {
        this.autoFocus = autoFocus2;
        return this;
    }

    public String getTextFromImage(String imagePath) {
        if (imagePath == null || imagePath.isEmpty()) {
            return "Image path is not valid";
        }
        Bitmap bitmap = Util.decodeSampledBitmapFromResource(imagePath, 500, 500);
        if (bitmap != null) {
            return getTextFromBitmap(bitmap);
        }
        return "Cannot read image from given path";
    }

    public String getTextFromUri(Uri imageUri) {
        if (imageUri == null) {
            return "Image path is not valid";
        }
        Bitmap bitmap = Util.decodeSampledBitmapFromResource(getPath(imageUri), 500, 500);
        if (bitmap == null) {
            try {
                bitmap = MediaStore.Images.Media.getBitmap(this.activity.getContentResolver(), imageUri);
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
        if (bitmap == null) {
            return "Cannot read image from given path";
        }
        Log.v(TAG, "Width : " + bitmap.getWidth() + ", Height : " + bitmap.getHeight());
        return getTextFromBitmap(bitmap);
    }

    public String getTextFromBitmap(Bitmap bitmap) {
        TextRecognizer textRecognizer = new TextRecognizer.Builder(this.activity).build();
        Frame imageFrame = new Frame.Builder().setBitmap(bitmap).build();
        StringBuilder imageText = new StringBuilder();
        SparseArray<TextBlock> textBlocks = textRecognizer.detect(imageFrame);
        TextBlock[] myTextBlocks = new TextBlock[textBlocks.size()];
        for (int i = 0; i < textBlocks.size(); i++) {
            myTextBlocks[i] = textBlocks.get(textBlocks.keyAt(i));
        }
        Arrays.sort(myTextBlocks, Util.TextBlockComparator);
        for (TextBlock textBlock : myTextBlocks) {
            if (imageText.toString().equals("")) {
                imageText.append(textBlock.getValue());
            } else {
                imageText.append("\n");
                imageText.append(textBlock.getValue());
            }
        }
        return imageText.toString();
    }

    public void buildWithRequestCode(int requestCode) {
        Intent intent = new Intent(this.activity, OcrCaptureActivity.class);
        intent.putExtra(OcrCaptureActivity.UseFlash, this.useFlash);
        intent.putExtra(OcrCaptureActivity.AutoFocus, this.autoFocus);
        this.activity.startActivityForResult(intent, requestCode);
    }

    private String getPath(Uri contentUri) {
        Cursor cursor = null;
        try {
            cursor = this.activity.getContentResolver().query(contentUri, new String[]{"_data"}, (String) null, (String[]) null, (String) null);
            int column_index = cursor.getColumnIndexOrThrow("_data");
            cursor.moveToFirst();
            return cursor.getString(column_index);
        } finally {
            if (cursor != null) {
                cursor.close();
            }
        }
    }
}
