package com.guna.ocrlibrary;

import android.annotation.SuppressLint;
import android.app.AlertDialog;
import android.content.BroadcastReceiver;
import android.content.DialogInterface;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Bundle;
//import android.support.annotation.NonNull;
//import android.support.design.widget.Snackbar;
//import android.support.v4.app.ActivityCompat;
//import android.support.v7.app.AppCompatActivity;
import android.util.Log;
import android.view.GestureDetector;
import android.view.MotionEvent;
import android.view.ScaleGestureDetector;
import android.view.View;
import android.widget.Toast;
import com.google.android.gms.common.GoogleApiAvailability;
import com.google.android.gms.vision.text.TextBlock;
import com.google.android.gms.vision.text.TextRecognizer;
import com.google.android.material.snackbar.BaseTransientBottomBar;
import com.google.android.material.snackbar.Snackbar;
import com.guna.ocrlibrary.camera.CameraSource;
import com.guna.ocrlibrary.camera.CameraSourcePreview;
import com.guna.ocrlibrary.camera.GraphicOverlay;
import com.guna.ocrlibrary.camera.util.OcrDetectorProcessor;
import com.guna.ocrlibrary.camera.util.OcrGraphic;
import com.voicetextcamera.translation.R;

import java.io.IOException;
import java.util.Arrays;
import java.util.Set;

import androidx.annotation.NonNull;
import androidx.appcompat.app.AppCompatActivity;
import androidx.core.app.ActivityCompat;

public final class OcrCaptureActivity extends AppCompatActivity {
    public static final String AutoFocus = "AutoFocus";
    private static final int RC_HANDLE_CAMERA_PERM = 2;
    private static final int RC_HANDLE_GMS = 9001;
    private static final String TAG = "OcrCaptureActivity";
    public static final String TextBlockObject = "String";
    public static final String UseFlash = "UseFlash";
    private GestureDetector gestureDetector;
    
    public CameraSource mCameraSource;
    private GraphicOverlay<OcrGraphic> mGraphicOverlay;
    private CameraSourcePreview mPreview;
    private ScaleGestureDetector scaleGestureDetector;

    public void onCreate(Bundle icicle) {
        super.onCreate(icicle);
        setContentView(R.layout.ocr_capture);
        this.mPreview = (CameraSourcePreview) findViewById(R.id.preview);
        this.mGraphicOverlay = (GraphicOverlay) findViewById(R.id.graphicOverlay);
        boolean autoFocus = getIntent().getBooleanExtra(AutoFocus, false);
        boolean useFlash = getIntent().getBooleanExtra(UseFlash, false);
        if (ActivityCompat.checkSelfPermission(this, "android.permission.CAMERA") == 0) {
            createCameraSource(autoFocus, useFlash);
        } else {
            requestCameraPermission();
        }
        this.gestureDetector = new GestureDetector(this, new CaptureGestureListener());
        this.scaleGestureDetector = new ScaleGestureDetector(this, new ScaleListener());
        Snackbar.make((View) this.mGraphicOverlay, (CharSequence) "Tap to capture. Pinch/Stretch to zoom", 0).show();
    }

    private void requestCameraPermission() {
        Log.w(TAG, "Camera permission is not granted. Requesting permission");
        final String[] permissions = {"android.permission.CAMERA"};
        if (!ActivityCompat.shouldShowRequestPermissionRationale(this, "android.permission.CAMERA")) {
            ActivityCompat.requestPermissions(this, permissions, 2);
            return;
        }
        Snackbar.make((View) this.mGraphicOverlay, R.string.permission_camera_rationale, BaseTransientBottomBar.LENGTH_INDEFINITE).setAction(R.string.ok, new View.OnClickListener() {
            public void onClick(View view) {
                ActivityCompat.requestPermissions(OcrCaptureActivity.this, permissions, 2);
            }
        }).show();
    }

    public boolean onTouchEvent(MotionEvent e) {
        return this.scaleGestureDetector.onTouchEvent(e) || this.gestureDetector.onTouchEvent(e) || super.onTouchEvent(e);
    }

    @SuppressLint({"InlinedApi"})
    private void createCameraSource(boolean autoFocus, boolean useFlash) {
        String str;
        boolean hasLowStorage;
        String str2 = null;
        TextRecognizer textRecognizer = new TextRecognizer.Builder(getApplicationContext()).build();
        textRecognizer.setProcessor(new OcrDetectorProcessor(this.mGraphicOverlay));
        if (!textRecognizer.isOperational()) {
            Log.w(TAG, "Detector dependencies are not yet available.");
            if (registerReceiver((BroadcastReceiver) null, new IntentFilter("android.intent.action.DEVICE_STORAGE_LOW")) != null) {
                hasLowStorage = true;
            } else {
                hasLowStorage = false;
            }
            if (hasLowStorage) {
                Toast.makeText(this, R.string.low_storage_error, 1).show();
                Log.w(TAG, getString(R.string.low_storage_error));
            }
        }
        CameraSource.Builder requestedFps = new CameraSource.Builder(getApplicationContext(), textRecognizer).setFacing(0).setRequestedPreviewSize(1280, 1024).setRequestedFps(2.0f);
        if (useFlash) {
            str = "torch";
        } else {
            str = null;
        }
        CameraSource.Builder flashMode = requestedFps.setFlashMode(str);
        if (autoFocus) {
            str2 = "continuous-picture";
        }
        this.mCameraSource = flashMode.setFocusMode(str2).build();
    }


    public void onResume() {
        super.onResume();
        startCameraSource();
    }


    public void onPause() {
        super.onPause();
        if (this.mPreview != null) {
            this.mPreview.stop();
        }
    }


    public void onDestroy() {
        super.onDestroy();
        if (this.mPreview != null) {
            this.mPreview.release();
        }
    }

    public void onRequestPermissionsResult(int requestCode, @NonNull String[] permissions, @NonNull int[] grantResults) {
        if (requestCode != 2) {
            Log.d(TAG, "Got unexpected permission result: " + requestCode);
            super.onRequestPermissionsResult(requestCode, permissions, grantResults);
        } else if (grantResults.length == 0 || grantResults[0] != 0) {
            Log.e(TAG, "Permission not granted: results len = " + grantResults.length + " Result code = " + (grantResults.length > 0 ? Integer.valueOf(grantResults[0]) : "(empty)"));
            new AlertDialog.Builder(this).setTitle("Multitracker sample").setMessage(R.string.no_camera_permission).setPositiveButton(R.string.ok, new DialogInterface.OnClickListener() {
                public void onClick(DialogInterface dialog, int id) {
                    OcrCaptureActivity.this.finish();
                }
            }).show();
        } else {
            Log.d(TAG, "Camera permission granted - initialize the camera source");
            createCameraSource(getIntent().getBooleanExtra(AutoFocus, false), getIntent().getBooleanExtra(UseFlash, false));
        }
    }

    private void startCameraSource() throws SecurityException {
        int code = GoogleApiAvailability.getInstance().isGooglePlayServicesAvailable(getApplicationContext());
        if (code != 0) {
            GoogleApiAvailability.getInstance().getErrorDialog(this, code, RC_HANDLE_GMS).show();
        }
        if (this.mCameraSource != null) {
            try {
                this.mPreview.start(this.mCameraSource, this.mGraphicOverlay);
            } catch (IOException e) {
                Log.e(TAG, "Unable to start camera source.", e);
                this.mCameraSource.release();
                this.mCameraSource = null;
            }
        }
    }

    
    public boolean onTap(float rawX, float rawY) {
        OcrGraphic graphic = this.mGraphicOverlay.getGraphicAtLocation(rawX, rawY);
        TextBlock text = null;
        if (graphic != null) {
            text = graphic.getTextBlock();
            if (text == null || text.getValue() == null) {
                Log.d(TAG, "text data is null");
            } else {
                Intent data = new Intent();
                data.putExtra(TextBlockObject, text.getValue());
                setResult(0, data);
                finish();
            }
        } else {
            Log.d(TAG, "no text detected");
        }
        if (text != null) {
            return true;
        }
        return false;
    }

    public void selectAll(View view) {
        Set<OcrGraphic> graphic = this.mGraphicOverlay.getGraphic();
        if (graphic == null || graphic.size() <= 0) {
            Log.d(TAG, "no text detected");
            return;
        }
        OcrGraphic[] myGraphic = (OcrGraphic[]) graphic.toArray(new OcrGraphic[graphic.size()]);
        Arrays.sort(myGraphic);
        StringBuilder mText = new StringBuilder();
        for (OcrGraphic mGraphic : myGraphic) {
            TextBlock text = mGraphic.getTextBlock();
            if (text == null || text.getValue() == null) {
                Log.d(TAG, "text data is null");
            } else if (mText.toString().equals("")) {
                mText.append(text.getValue());
            } else {
                mText.append("\n");
                mText.append(text.getValue());
            }
        }
        if (mText.length() != 0) {
            Intent data = new Intent();
            data.putExtra(TextBlockObject, mText.toString());
            setResult(0, data);
            finish();
        }
    }

    private class CaptureGestureListener extends GestureDetector.SimpleOnGestureListener {
        private CaptureGestureListener() {
        }

        public boolean onSingleTapConfirmed(MotionEvent e) {
            return OcrCaptureActivity.this.onTap(e.getRawX(), e.getRawY()) || super.onSingleTapConfirmed(e);
        }
    }

    private class ScaleListener implements ScaleGestureDetector.OnScaleGestureListener {
        private ScaleListener() {
        }

        public boolean onScale(ScaleGestureDetector detector) {
            return false;
        }

        public boolean onScaleBegin(ScaleGestureDetector detector) {
            return true;
        }

        public void onScaleEnd(ScaleGestureDetector detector) {
            OcrCaptureActivity.this.mCameraSource.doZoom(detector.getScaleFactor());
        }
    }
}
