package com.guna.ocrlibrary.camera;

import android.annotation.SuppressLint;
import android.annotation.TargetApi;
import android.content.Context;
import android.graphics.ImageFormat;
import android.graphics.SurfaceTexture;
import android.hardware.Camera;
import android.os.Build;
import android.os.SystemClock;
//import android.support.annotation.Nullable;
//import android.support.annotation.RequiresPermission;
//import android.support.v7.widget.ActivityChooserView;
import android.util.Log;
import android.view.SurfaceHolder;
import android.view.SurfaceView;
import android.view.WindowManager;
import com.google.android.gms.common.images.Size;
import com.google.android.gms.vision.Detector;
import com.google.android.gms.vision.Frame;
import java.io.IOException;
import java.lang.Thread;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.nio.ByteBuffer;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

import androidx.annotation.Nullable;
import androidx.annotation.RequiresPermission;

public class CameraSource {
    private static final float ASPECT_RATIO_TOLERANCE = 0.01f;
    @SuppressLint({"InlinedApi"})
    public static final int CAMERA_FACING_BACK = 0;
    @SuppressLint({"InlinedApi"})
    public static final int CAMERA_FACING_FRONT = 1;
    private static final int DUMMY_TEXTURE_NAME = 100;
    private static final String TAG = "OpenCameraSource";
    
    public static Map<byte[], ByteBuffer> mBytesToByteBuffer;
    
    public Camera mCamera;
    
    public final Object mCameraLock;
    
    public Context mContext;
    private SurfaceTexture mDummySurfaceTexture;
    private SurfaceView mDummySurfaceView;
    
    public int mFacing;
    
    public String mFlashMode;
    
    public String mFocusMode;
    
    public FrameProcessingRunnable mFrameProcessor;
    
    public static Size mPreviewSize;
    
    public static Thread mProcessingThread;
    
    public float mRequestedFps;
    
    public int mRequestedPreviewHeight;
    
    public int mRequestedPreviewWidth;
    
    public static int mRotation;

    public interface AutoFocusCallback {
        void onAutoFocus(boolean z);
    }

    public interface AutoFocusMoveCallback {
        void onAutoFocusMoving(boolean z);
    }

    @Retention(RetentionPolicy.SOURCE)
    private @interface FlashMode {
    }

    @Retention(RetentionPolicy.SOURCE)
    private @interface FocusMode {
    }

    public interface PictureCallback {
        void onPictureTaken(byte[] bArr);
    }

    public interface ShutterCallback {
        void onShutter();
    }

    public static class Builder {
        private CameraSource mCameraSource = new CameraSource();
        private final Detector<?> mDetector;

        public Builder(Context context, Detector<?> detector) {
            if (context == null) {
                throw new IllegalArgumentException("No context supplied.");
            } else if (detector == null) {
                throw new IllegalArgumentException("No detector supplied.");
            } else {
                this.mDetector = detector;
                Context unused = this.mCameraSource.mContext = context;
            }
        }

        public Builder setRequestedFps(float fps) {
            if (fps <= 0.0f) {
                throw new IllegalArgumentException("Invalid fps: " + fps);
            }
            float unused = this.mCameraSource.mRequestedFps = fps;
            return this;
        }

        public Builder setFocusMode(String mode) {
            String unused = this.mCameraSource.mFocusMode = mode;
            return this;
        }

        public Builder setFlashMode(String mode) {
            String unused = this.mCameraSource.mFlashMode = mode;
            return this;
        }

        public Builder setRequestedPreviewSize(int width, int height) {
            if (width <= 0 || width > 1000000 || height <= 0 || height > 1000000) {
                throw new IllegalArgumentException("Invalid preview size: " + width + "x" + height);
            }
            int unused = this.mCameraSource.mRequestedPreviewWidth = width;
            int unused2 = this.mCameraSource.mRequestedPreviewHeight = height;
            return this;
        }

        public Builder setFacing(int facing) {
            if (facing == 0 || facing == 1) {
                int unused = this.mCameraSource.mFacing = facing;
                return this;
            }
            throw new IllegalArgumentException("Invalid camera: " + facing);
        }

        public CameraSource build() {
            CameraSource cameraSource = this.mCameraSource;
            CameraSource cameraSource2 = this.mCameraSource;
            cameraSource2.getClass();
            FrameProcessingRunnable unused = cameraSource.mFrameProcessor = new FrameProcessingRunnable(this.mDetector);
            return this.mCameraSource;
        }
    }

    public void release() {
        synchronized (this.mCameraLock) {
            stop();
            this.mFrameProcessor.release();
        }
    }

    @RequiresPermission("android.permission.CAMERA")
    public CameraSource start() throws IOException {
        synchronized (this.mCameraLock) {
            if (this.mCamera == null) {
                this.mCamera = createCamera();
                if (Build.VERSION.SDK_INT >= 11) {
                    this.mDummySurfaceTexture = new SurfaceTexture(100);
                    this.mCamera.setPreviewTexture(this.mDummySurfaceTexture);
                } else {
                    this.mDummySurfaceView = new SurfaceView(this.mContext);
                    this.mCamera.setPreviewDisplay(this.mDummySurfaceView.getHolder());
                }
                this.mCamera.startPreview();
                this.mProcessingThread = new Thread(this.mFrameProcessor);
                this.mFrameProcessor.setActive(true);
                this.mProcessingThread.start();
            }
        }
        return this;
    }

    @RequiresPermission("android.permission.CAMERA")
    public CameraSource start(SurfaceHolder surfaceHolder) throws IOException {
        synchronized (this.mCameraLock) {
            if (this.mCamera == null) {
                this.mCamera = createCamera();
                this.mCamera.setPreviewDisplay(surfaceHolder);
                this.mCamera.startPreview();
                this.mProcessingThread = new Thread(this.mFrameProcessor);
                this.mFrameProcessor.setActive(true);
                this.mProcessingThread.start();
            }
        }
        return this;
    }

    public void stop() {
        synchronized (this.mCameraLock) {
            this.mFrameProcessor.setActive(false);
            if (this.mProcessingThread != null) {
                try {
                    this.mProcessingThread.join();
                } catch (InterruptedException e) {
                    Log.d(TAG, "Frame processing thread interrupted on release.");
                }
                this.mProcessingThread = null;
            }
            this.mBytesToByteBuffer.clear();
            if (this.mCamera != null) {
                this.mCamera.stopPreview();
                this.mCamera.setPreviewCallbackWithBuffer((Camera.PreviewCallback) null);
                try {
                    if (Build.VERSION.SDK_INT >= 11) {
                        this.mCamera.setPreviewTexture((SurfaceTexture) null);
                    } else {
                        this.mCamera.setPreviewDisplay((SurfaceHolder) null);
                    }
                } catch (Exception e2) {
                    Log.e(TAG, "Failed to clear camera preview: " + e2);
                }
                this.mCamera.release();
                this.mCamera = null;
            }
        }
        return;
    }

    public Size getPreviewSize() {
        return this.mPreviewSize;
    }

    public int getCameraFacing() {
        return this.mFacing;
    }

    public int doZoom(float scale) {
        int currentZoom;
        float newZoom;
        synchronized (this.mCameraLock) {
            if (this.mCamera == null) {
                currentZoom = 0;
            } else {
                currentZoom = 0;
                Camera.Parameters parameters = this.mCamera.getParameters();
                if (!parameters.isZoomSupported()) {
                    Log.w(TAG, "Zoom is not supported on this device");
                } else {
                    int maxZoom = parameters.getMaxZoom();
                    int currentZoom2 = parameters.getZoom() + 1;
                    if (scale > 1.0f) {
                        newZoom = ((float) currentZoom2) + (((float) (maxZoom / 10)) * scale);
                    } else {
                        newZoom = ((float) currentZoom2) * scale;
                    }
                    currentZoom = Math.round(newZoom) - 1;
                    if (currentZoom < 0) {
                        currentZoom = 0;
                    } else if (currentZoom > maxZoom) {
                        currentZoom = maxZoom;
                    }
                    parameters.setZoom(currentZoom);
                    this.mCamera.setParameters(parameters);
                }
            }
        }
        return currentZoom;
    }

    public void takePicture(ShutterCallback shutter, PictureCallback jpeg) {
        synchronized (this.mCameraLock) {
            if (this.mCamera != null) {
                PictureStartCallback startCallback = new PictureStartCallback();
                ShutterCallback unused = startCallback.mDelegate = shutter;
                PictureDoneCallback doneCallback = new PictureDoneCallback();
                PictureCallback unused2 = doneCallback.mDelegate = jpeg;
                this.mCamera.takePicture(startCallback, (Camera.PictureCallback) null, (Camera.PictureCallback) null, doneCallback);
            }
        }
    }

    @Nullable
    public String getFocusMode() {
        return this.mFocusMode;
    }

    public boolean setFocusMode(String mode) {
        boolean z;
        synchronized (this.mCameraLock) {
            if (!(this.mCamera == null || mode == null)) {
                Camera.Parameters parameters = this.mCamera.getParameters();
                if (parameters.getSupportedFocusModes().contains(mode)) {
                    parameters.setFocusMode(mode);
                    this.mCamera.setParameters(parameters);
                    this.mFocusMode = mode;
                    z = true;
                }
            }
            z = false;
        }
        return z;
    }

    @Nullable
    public String getFlashMode() {
        return this.mFlashMode;
    }

    public boolean setFlashMode(String mode) {
        boolean z;
        synchronized (this.mCameraLock) {
            if (!(this.mCamera == null || mode == null)) {
                Camera.Parameters parameters = this.mCamera.getParameters();
                if (parameters.getSupportedFlashModes().contains(mode)) {
                    parameters.setFlashMode(mode);
                    this.mCamera.setParameters(parameters);
                    this.mFlashMode = mode;
                    z = true;
                }
            }
            z = false;
        }
        return z;
    }

    public void autoFocus(@Nullable AutoFocusCallback cb) {
        synchronized (this.mCameraLock) {
            if (this.mCamera != null) {
                CameraAutoFocusCallback autoFocusCallback = null;
                if (cb != null) {
                    autoFocusCallback = new CameraAutoFocusCallback();
                    AutoFocusCallback unused = autoFocusCallback.mDelegate = cb;
                }
                this.mCamera.autoFocus(autoFocusCallback);
            }
        }
    }

    public void cancelAutoFocus() {
        synchronized (this.mCameraLock) {
            if (this.mCamera != null) {
                this.mCamera.cancelAutoFocus();
            }
        }
    }

    @TargetApi(16)
    public boolean setAutoFocusMoveCallback(@Nullable AutoFocusMoveCallback cb) {
        if (Build.VERSION.SDK_INT < 16) {
            return false;
        }
        synchronized (this.mCameraLock) {
            if (this.mCamera != null) {
                CameraAutoFocusMoveCallback autoFocusMoveCallback = null;
                if (cb != null) {
                    autoFocusMoveCallback = new CameraAutoFocusMoveCallback();
                    AutoFocusMoveCallback unused = autoFocusMoveCallback.mDelegate = cb;
                }
                this.mCamera.setAutoFocusMoveCallback(autoFocusMoveCallback);
            }
        }
        return true;
    }

    private CameraSource() {
        this.mCameraLock = new Object();
        this.mFacing = 0;
        this.mRequestedFps = 30.0f;
        this.mRequestedPreviewWidth = 1024;
        this.mRequestedPreviewHeight = 768;
        this.mFocusMode = null;
        this.mFlashMode = null;
        this.mBytesToByteBuffer = new HashMap();
    }

    private class PictureStartCallback implements Camera.ShutterCallback {
        
        public ShutterCallback mDelegate;

        private PictureStartCallback() {
        }

        public void onShutter() {
            if (this.mDelegate != null) {
                this.mDelegate.onShutter();
            }
        }
    }

    private class PictureDoneCallback implements Camera.PictureCallback {
        
        public PictureCallback mDelegate;

        private PictureDoneCallback() {
        }

        public void onPictureTaken(byte[] data, Camera camera) {
            if (this.mDelegate != null) {
                this.mDelegate.onPictureTaken(data);
            }
            synchronized (CameraSource.this.mCameraLock) {
                if (CameraSource.this.mCamera != null) {
                    CameraSource.this.mCamera.startPreview();
                }
            }
        }
    }

    private class CameraAutoFocusCallback implements Camera.AutoFocusCallback {
        
        public AutoFocusCallback mDelegate;

        private CameraAutoFocusCallback() {
        }

        public void onAutoFocus(boolean success, Camera camera) {
            if (this.mDelegate != null) {
                this.mDelegate.onAutoFocus(success);
            }
        }
    }

    @TargetApi(16)
    private class CameraAutoFocusMoveCallback implements Camera.AutoFocusMoveCallback {
        
        public AutoFocusMoveCallback mDelegate;

        private CameraAutoFocusMoveCallback() {
        }

        public void onAutoFocusMoving(boolean start, Camera camera) {
            if (this.mDelegate != null) {
                this.mDelegate.onAutoFocusMoving(start);
            }
        }
    }

    @SuppressLint({"InlinedApi"})
    private Camera createCamera() {
        int requestedCameraId = getIdForRequestedCamera(this.mFacing);
        if (requestedCameraId == -1) {
            throw new RuntimeException("Could not find requested camera.");
        }
        Camera camera = Camera.open(requestedCameraId);
        SizePair sizePair = selectSizePair(camera, this.mRequestedPreviewWidth, this.mRequestedPreviewHeight);
        if (sizePair == null) {
            throw new RuntimeException("Could not find suitable preview size.");
        }
        Size pictureSize = sizePair.pictureSize();
        this.mPreviewSize = sizePair.previewSize();
        int[] previewFpsRange = selectPreviewFpsRange(camera, this.mRequestedFps);
        if (previewFpsRange == null) {
            throw new RuntimeException("Could not find suitable preview frames per second range.");
        }
        Camera.Parameters parameters = camera.getParameters();
        if (pictureSize != null) {
            parameters.setPictureSize(pictureSize.getWidth(), pictureSize.getHeight());
        }
        parameters.setPreviewSize(this.mPreviewSize.getWidth(), this.mPreviewSize.getHeight());
        parameters.setPreviewFpsRange(previewFpsRange[0], previewFpsRange[1]);
        parameters.setPreviewFormat(17);
        setRotation(camera, parameters, requestedCameraId);
        if (this.mFocusMode != null) {
            if (parameters.getSupportedFocusModes().contains(this.mFocusMode)) {
                parameters.setFocusMode(this.mFocusMode);
            } else {
                Log.i(TAG, "Camera focus mode: " + this.mFocusMode + " is not supported on this device.");
            }
        }
        this.mFocusMode = parameters.getFocusMode();
        if (this.mFlashMode != null) {
            if (parameters.getSupportedFlashModes().contains(this.mFlashMode)) {
                parameters.setFlashMode(this.mFlashMode);
            } else {
                Log.i(TAG, "Camera flash mode: " + this.mFlashMode + " is not supported on this device.");
            }
        }
        this.mFlashMode = parameters.getFlashMode();
        camera.setParameters(parameters);
        camera.setPreviewCallbackWithBuffer(new CameraPreviewCallback());
        camera.addCallbackBuffer(createPreviewBuffer(this.mPreviewSize));
        camera.addCallbackBuffer(createPreviewBuffer(this.mPreviewSize));
        camera.addCallbackBuffer(createPreviewBuffer(this.mPreviewSize));
        camera.addCallbackBuffer(createPreviewBuffer(this.mPreviewSize));
        return camera;
    }

    private static int getIdForRequestedCamera(int facing) {
        Camera.CameraInfo cameraInfo = new Camera.CameraInfo();
        for (int i = 0; i < Camera.getNumberOfCameras(); i++) {
            Camera.getCameraInfo(i, cameraInfo);
            if (cameraInfo.facing == facing) {
                return i;
            }
        }
        return -1;
    }

    private static SizePair selectSizePair(Camera camera, int desiredWidth, int desiredHeight) {
        List<SizePair> validPreviewSizes = generateValidPreviewSizeList(camera);
        SizePair selectedPair = null;
        int minDiff = Integer.MAX_VALUE;
        for (SizePair sizePair : validPreviewSizes) {
            Size size = sizePair.previewSize();
            int diff = Math.abs(size.getWidth() - desiredWidth) + Math.abs(size.getHeight() - desiredHeight);
            if (diff < minDiff) {
                selectedPair = sizePair;
                minDiff = diff;
            }
        }
        return selectedPair;
    }

    private static class SizePair {
        private Size mPicture;
        private Size mPreview;

        public SizePair(Camera.Size previewSize, Camera.Size pictureSize) {
            this.mPreview = new Size(previewSize.width, previewSize.height);
            if (pictureSize != null) {
                this.mPicture = new Size(pictureSize.width, pictureSize.height);
            }
        }

        public Size previewSize() {
            return this.mPreview;
        }

        public Size pictureSize() {
            return this.mPicture;
        }
    }

    private static List<SizePair> generateValidPreviewSizeList(Camera camera) {
        Camera.Parameters parameters = camera.getParameters();
        List<Camera.Size> supportedPreviewSizes = parameters.getSupportedPreviewSizes();
        List<Camera.Size> supportedPictureSizes = parameters.getSupportedPictureSizes();
        List<SizePair> validPreviewSizes = new ArrayList<>();
        for (Camera.Size previewSize : supportedPreviewSizes) {
            float previewAspectRatio = ((float) previewSize.width) / ((float) previewSize.height);
            Iterator<Camera.Size> it = supportedPictureSizes.iterator();
            while (true) {
                if (!it.hasNext()) {
                    break;
                }
                Camera.Size pictureSize = it.next();
                if (Math.abs(previewAspectRatio - (((float) pictureSize.width) / ((float) pictureSize.height))) < ASPECT_RATIO_TOLERANCE) {
                    validPreviewSizes.add(new SizePair(previewSize, pictureSize));
                    break;
                }
            }
        }
        if (validPreviewSizes.size() == 0) {
            Log.w(TAG, "No preview sizes have a corresponding same-aspect-ratio picture size");
            for (Camera.Size previewSize2 : supportedPreviewSizes) {
                validPreviewSizes.add(new SizePair(previewSize2, (Camera.Size) null));
            }
        }
        return validPreviewSizes;
    }

    private int[] selectPreviewFpsRange(Camera camera, float desiredPreviewFps) {
        int desiredPreviewFpsScaled = (int) (1000.0f * desiredPreviewFps);
        int[] selectedFpsRange = null;
        int minDiff = Integer.MAX_VALUE;
        for (int[] range : camera.getParameters().getSupportedPreviewFpsRange()) {
            int diff = Math.abs(desiredPreviewFpsScaled - range[0]) + Math.abs(desiredPreviewFpsScaled - range[1]);
            if (diff < minDiff) {
                selectedFpsRange = range;
                minDiff = diff;
            }
        }
        return selectedFpsRange;
    }

    private void setRotation(Camera camera, Camera.Parameters parameters, int cameraId) {
        int angle;
        int displayAngle;
        int degrees = 0;
        int rotation = ((WindowManager) this.mContext.getSystemService("window")).getDefaultDisplay().getRotation();
        switch (rotation) {
            case 0:
                degrees = 0;
                break;
            case 1:
                degrees = 90;
                break;
            case 2:
                degrees = 180;
                break;
            case 3:
                degrees = 270;
                break;
            default:
                Log.e(TAG, "Bad rotation value: " + rotation);
                break;
        }
        Camera.CameraInfo cameraInfo = new Camera.CameraInfo();
        Camera.getCameraInfo(cameraId, cameraInfo);
        if (cameraInfo.facing == 1) {
            angle = (cameraInfo.orientation + degrees) % 360;
            displayAngle = 360 - angle;
        } else {
            angle = ((cameraInfo.orientation - degrees) + 360) % 360;
            displayAngle = angle;
        }
        this.mRotation = angle / 90;
        camera.setDisplayOrientation(displayAngle);
        parameters.setRotation(angle);
    }

    private byte[] createPreviewBuffer(Size previewSize) {
        byte[] byteArray = new byte[(((int) Math.ceil(((double) ((long) ((previewSize.getHeight() * previewSize.getWidth()) * ImageFormat.getBitsPerPixel(17)))) / 8.0d)) + 1)];
        ByteBuffer buffer = ByteBuffer.wrap(byteArray);
        if (!buffer.hasArray() || buffer.array() != byteArray) {
            throw new IllegalStateException("Failed to create valid buffer for camera source.");
        }
        this.mBytesToByteBuffer.put(byteArray, buffer);
        return byteArray;
    }

    private class CameraPreviewCallback implements Camera.PreviewCallback {
        private CameraPreviewCallback() {
        }

        public void onPreviewFrame(byte[] data, Camera camera) {
            CameraSource.this.mFrameProcessor.setNextFrame(data, camera);
        }
    }

    private static class FrameProcessingRunnable implements Runnable {
        final  boolean $assertionsDisabled = (!CameraSource.class.desiredAssertionStatus());
        private boolean mActive = true;
        private Detector<?> mDetector;
        private final Object mLock = new Object();
        private ByteBuffer mPendingFrameData;
        private int mPendingFrameId = 0;
        private long mPendingTimeMillis;
        private long mStartTimeMillis = SystemClock.elapsedRealtime();

        FrameProcessingRunnable(Detector<?> detector) {
            this.mDetector = detector;
        }

        @SuppressLint({"Assert"})
        public void release() {
            if ($assertionsDisabled || mProcessingThread.getState() == Thread.State.TERMINATED) {
                this.mDetector.release();
                this.mDetector = null;
                return;
            }
            throw new AssertionError();
        }

        public void setActive(boolean active) {
            synchronized (this.mLock) {
                this.mActive = active;
                this.mLock.notifyAll();
            }
        }

        public void setNextFrame(byte[] data, Camera camera) {
            synchronized (this.mLock) {
                if (this.mPendingFrameData != null) {
                    camera.addCallbackBuffer(this.mPendingFrameData.array());
                    this.mPendingFrameData = null;
                }
                if (!mBytesToByteBuffer.containsKey(data)) {
                    Log.d(CameraSource.TAG, "Skipping frame.  Could not find ByteBuffer associated with the image data from the camera.");
                    return;
                }
                this.mPendingTimeMillis = SystemClock.elapsedRealtime() - this.mStartTimeMillis;
                this.mPendingFrameId++;
                this.mPendingFrameData = (ByteBuffer) mBytesToByteBuffer.get(data);
                this.mLock.notifyAll();
            }
        }

        public void run() {
            while (true) {
                synchronized (this.mLock) {
                    while (this.mActive && this.mPendingFrameData == null) {
                        try {
                            this.mLock.wait();
                        } catch (InterruptedException e) {
                            Log.d(CameraSource.TAG, "Frame processing loop terminated.", e);
                            return;
                        }
                    }
                    if (this.mActive) {
                        Frame outputFrame = new Frame.Builder().setImageData(this.mPendingFrameData, mPreviewSize.getWidth(), mPreviewSize.getHeight(), 17).setId(this.mPendingFrameId).setTimestampMillis(this.mPendingTimeMillis).setRotation(mRotation).build();
                        ByteBuffer data = this.mPendingFrameData;
                        this.mPendingFrameData = null;
                    } else {
                        return;
                    }
                }
            }
        }
    }
}
