package com.guna.ocrlibrary.camera.util;

import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.RectF;
//import android.support.annotation.NonNull;
import com.google.android.gms.vision.text.Text;
import com.google.android.gms.vision.text.TextBlock;
import com.guna.ocrlibrary.camera.GraphicOverlay;

import androidx.annotation.NonNull;

public class OcrGraphic extends GraphicOverlay.Graphic implements Comparable<OcrGraphic> {
    private static final int TEXT_COLOR = -1;
    private static Paint sRectPaint;
    private static Paint sTextPaint;
    private int mId;
    private final TextBlock mText;

    OcrGraphic(GraphicOverlay overlay, TextBlock text) {
        super(overlay);
        this.mText = text;
        if (sRectPaint == null) {
            sRectPaint = new Paint();
            sRectPaint.setColor(-1);
            sRectPaint.setStyle(Paint.Style.STROKE);
            sRectPaint.setStrokeWidth(4.0f);
        }
        if (sTextPaint == null) {
            sTextPaint = new Paint();
            sTextPaint.setColor(-1);
            sTextPaint.setTextSize(54.0f);
        }
        postInvalidate();
    }

    public int getId() {
        return this.mId;
    }

    public void setId(int id) {
        this.mId = id;
    }

    public TextBlock getTextBlock() {
        return this.mText;
    }

    public boolean contains(float x, float y) {
        TextBlock text = this.mText;
        if (text == null) {
            return false;
        }
        RectF rect = new RectF(text.getBoundingBox());
        rect.left = translateX(rect.left);
        rect.top = translateY(rect.top);
        rect.right = translateX(rect.right);
        rect.bottom = translateY(rect.bottom);
        if (rect.left >= x || rect.right <= x || rect.top >= y || rect.bottom <= y) {
            return false;
        }
        return true;
    }

    public void draw(Canvas canvas) {
        TextBlock text = this.mText;
        if (text != null) {
            RectF rect = new RectF(text.getBoundingBox());
            rect.left = translateX(rect.left);
            rect.top = translateY(rect.top);
            rect.right = translateX(rect.right);
            rect.bottom = translateY(rect.bottom);
            canvas.drawRect(rect, sRectPaint);
            for (Text currentText : text.getComponents()) {
                canvas.drawText(currentText.getValue(), translateX((float) currentText.getBoundingBox().left), translateY((float) currentText.getBoundingBox().bottom), sTextPaint);
            }
        }
    }

    public int compareTo(@NonNull OcrGraphic o) {
        return this.mText.getBoundingBox().bottom - o.mText.getBoundingBox().bottom;
    }
}
